# The Solver for PyTorch

[![downloads](https://pepy.tech/badge/thsolver)](https://pepy.tech/project/thsolver)
[![PyPI](https://img.shields.io/pypi/v/thsolver)](https://pypi.org/project/thsolver/)


The code can be used for training/testing PyTorch models. It is used in the
[O-CNN](https://github.com/octree-nn/ocnn-pytorch) and my daily experiments.

It is similar to `pytorch-lightning`, but with much simpler implementations.
